encoder

package
v0.0.0-...-c469508 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 19, 2022 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IncludeRaw

func IncludeRaw(filename, constName string) (string, error)

IncludeRaw embeds original file content.

func JSONToStructs

func JSONToStructs(filename string, rootStructName string, force64 bool) (string, error)

JSONToStructs validates and dumps the Go structs declarations of a JSON file.

func JSONToValues

func JSONToValues(filename string, funcName, rootStructName string, force64 bool) (string, error)

JSONToValues render an init function that returns the values of a JSON file.

func WriteFile

func WriteFile(filename, content string) error

WriteFile writes string to file.

Types

This section is empty.

Jump to