Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IncludeRaw ¶
IncludeRaw embeds original file content.
func JSONToStructs ¶
JSONToStructs validates and dumps the Go structs declarations of a JSON file.
func JSONToValues ¶
JSONToValues render an init function that returns the values of a JSON file.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.